==> guiCrudApi-8.2-sources.jar: org/fryske_akademy/jsf/AbstractController.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.fryske_akademy.jsf;

/*-
 * #%L
 * guiCrudApi
 * %%
 * Copyright (C) 2018 Fryske Akademy
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
import java.io.Serializable;
import org.fryske_akademy.ejb.CrudWriteService;
import org.fryske_akademy.jpa.EntityInterface;
import org.fryske_akademy.jsf.util.JsfUtil;

/**
 * Controller for views that are not single entity oriented
 *
 * @author eduard
 */
public abstract class AbstractController<S extends CrudWriteService> implements Serializable {

    private S crudWriteService;

    public final S getCrudWriteService() {
        if (crudWriteService == null) {
            throw new IllegalStateException("Please inject crudWriteService via initCrudWriteService() and a call to setCrudWriteService()");
        }
        return crudWriteService;
    }

    /**
     * Call {@link #persist(org.fryske_akademy.jpa.EntityInterface, org.fryske_akademy.jsf.util.JsfUtil.PersistAction, java.lang.String) }
     * with persisAction + " success"
     * @param <T>
     * @param edited
     * @param persistAction
     * @return 
     */
    protected <T extends EntityInterface> T persist(T edited, JsfUtil.PersistAction persistAction) {
        return persist(edited, persistAction, persistAction + " success");
    }
    
    /**
     * Calls {@link CrudWriteService#create(java.io.Serializable) }, update or
     * delete, calls {@link JsfUtil#addSuccessMessage(java.lang.String) } with
     * the succesMessage appended with the entity id, and in case of an exception calls {@link JsfUtil#handleException(java.lang.Exception, java.lang.String)
     * }.
     * @param edited
     * @param persistAction
     * @param successMessage the message with the entity id appended
     * @return the up to date or deleted entity
     */
    protected <T extends EntityInterface> T persist(T edited, JsfUtil.PersistAction persistAction, String successMessage) {
        if (edited != null) {
            try {
                switch (persistAction) {
                    case CREATE:
                        edited = crudWriteService.create(edited);
                        break;
                    case UPDATE:
                        edited = crudWriteService.update(edited);
                        break;
                    case DELETE:
                        crudWriteService.delete(edited);
                        break;
                }
                JsfUtil.addSuccessMessage(successMessage + " " + edited.getId());
            } catch (Exception ex) {
                JsfUtil.handleException(ex, persistAction + " " + edited + " failed: ");
            }
        }
        return edited;
    }

    /**
     * for use in primefaces keyboard layoutTemplate
     *
     * @return
     */
    public String diacriticsKeyBoard() {
        return "àáäâÀÁÂÄåÅ-back,èéëêÈÉÊË-clear,ìíïîÌÍÎÏ-close,òóöôÒÓÔÖ,ùúüûÙÚÛÜ,*?";
    }

    /**
     * call this from your Inject annotated set method
     *
     * @param crudWriteService
     */
    protected final void setCrudWriteService(S crudWriteService) {
        this.crudWriteService = crudWriteService;
    }

    /**
     * implement, annotate with @Inject (@EJB should work but no success yet)
     * and call {@link #setCrudWriteService(org.fryske_akademy.ejb.CrudWriteService)
     * }
     *
     * @param crudWriteService
     */
    protected abstract void initCrudWriteService(S crudWriteService);

    /**
     * can be appended to an outcome of an action is a redirect is desired.
     */
    public static final String FACESREDIRECTTRUE = "?faces-redirect=true";

}

==> guiCrudApi-8.6-sources.jar: org/fryske_akademy/jsf/AbstractController.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.fryske_akademy.jsf;

/*-
 * #%L
 * guiCrudApi
 * %%
 * Copyright (C) 2018 Fryske Akademy
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
import java.io.Serializable;
import javax.faces.convert.Converter;
import javax.inject.Inject;
import javax.security.enterprise.SecurityContext;
import org.fryske_akademy.ejb.CrudWriteService;
import org.fryske_akademy.jpa.EntityInterface;
import org.fryske_akademy.jsf.util.JsfUtil;

/**
 * Controller for views that are not single entity oriented
 *
 * @author eduard
 */
public abstract class AbstractController<S extends CrudWriteService> implements Serializable {

    private S crudWriteService;

    public final S getCrudWriteService() {
        if (crudWriteService == null) {
            throw new IllegalStateException("Please inject crudWriteService via initCrudWriteService() and a call to setCrudWriteService()");
        }
        return crudWriteService;
    }

    /**
     * Call {@link #persist(org.fryske_akademy.jpa.EntityInterface, org.fryske_akademy.jsf.util.JsfUtil.PersistAction, java.lang.String) }
     * with persisAction + " success"
     * @param <T>
     * @param edited
     * @param persistAction
     * @return 
     */
    protected <T extends EntityInterface> T persist(T edited, JsfUtil.PersistAction persistAction) {
        return persist(edited, persistAction, persistAction + " success");
    }
    
    /**
     * Calls {@link CrudWriteService#create(java.io.Serializable) }, update or
     * delete, calls {@link JsfUtil#addSuccessMessage(java.lang.String) } with
     * the succesMessage appended with the entity (either converted by {@link Converter} or toString. 
     * In case of an exception calls {@link JsfUtil#handleException(java.lang.Exception, java.lang.String)}.
     * @param edited
     * @param persistAction
     * @param successMessage the message with the entity id appended
     * @return the up to date or deleted entity
     */
    protected <T extends EntityInterface> T persist(T edited, JsfUtil.PersistAction persistAction, String successMessage) {
        if (edited != null) {
            Converter converter = JsfUtil.getConverter(edited.getClass());
            try {
                switch (persistAction) {
                    case CREATE:
                        edited = crudWriteService.create(edited);
                        break;
                    case UPDATE:
                        edited = crudWriteService.update(edited);
                        break;
                    case DELETE:
                        crudWriteService.delete(edited);
                        break;
                }
                
                JsfUtil.addSuccessMessage(successMessage + " " + (converter!=null?converter.getAsString(null, null, edited):edited));
            } catch (Exception ex) {
                JsfUtil.handleException(ex, persistAction + " " + (converter!=null?converter.getAsString(null, null, edited):edited) + " failed: ");
            }
        }
        return edited;
    }

    /**
     * for use in primefaces keyboard layoutTemplate
     *
     * @return
     */
    public String diacriticsKeyBoard() {
        return "àáäâÀÁÂÄåÅ-back,èéëêÈÉÊË-clear,ìíïîÌÍÎÏ-close,òóöôÒÓÔÖ,ùúüûÙÚÛÜ,*?";
    }

    /**
     * call this from your Inject annotated set method
     *
     * @param crudWriteService
     */
    protected final void setCrudWriteService(S crudWriteService) {
        this.crudWriteService = crudWriteService;
    }

    /**
     * implement, annotate with @Inject (@EJB should work but no success yet)
     * and call {@link #setCrudWriteService(org.fryske_akademy.ejb.CrudWriteService)
     * }
     *
     * @param crudWriteService
     */
    protected abstract void initCrudWriteService(S crudWriteService);

    /**
     * can be appended to an outcome of an action is a redirect is desired.
     */
    public static final String FACESREDIRECTTRUE = "?faces-redirect=true";
    
    @Inject
    private SecurityContext securityContext;
    
    protected SecurityContext getSecurityContext() {
        return securityContext;
    }
    

}
